==> deepin-deepinid-plugin_2.0.8.tar.xz: BUILD/translations/dcc-deepinid-plugin_zh_CN.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_CN">
<context>
    <name>LoginInfoPage</name>
    <message>
        <source>Edit account</source>
        <translation>编辑账号信息</translation>
    </message>
    <message>
        <source>Sign out</source>
        <translation>退出登录</translation>
    </message>
    <message>
        <source>The nickname must be 1~32 characters long</source>
        <translation>昵称长度必须为1~32个字符</translation>
    </message>
    <message>
        <source>The full name is too long</source>
        <translation>名称过长</translation>
    </message>
    <message>
        <source>Mainland China</source>
        <translation>中国大陆</translation>
    </message>
    <message>
        <source>Other regions</source>
        <translation>港澳台及其他地区</translation>
    </message>
</context>
<context>
    <name>SyncModule</name>
    <message>
        <source>deepin ID</source>
        <translation>deepin ID</translation>
    </message>
    <message>
        <source>UOS ID</source>
        <translation>UOS ID</translation>
    </message>
    <message>
        <source>Cloud sync, app store and etc</source>
        <translation>云同步、应用商店等</translation>
    </message>
</context>
<context>
    <name>TransString</name>
    <message>
        <source>deepin Cloud Sync</source>
        <translation>deepin Cloud同步</translation>
    </message>
    <message>
        <source>Subject to your local laws and regulations, it is currently unavailable in your region.</source>
        <translation>受限于您当地的法律法规，UOS Cloud暂未覆盖您所在地区，敬请期待。</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取 消</translation>
    </message>
    <message>
        <source>Securely store system settings and personal data in the cloud, and keep them in sync across devices.</source>
        <translation>将您的系统设置和个人信息安全地存储在云端，并在您不同的设备上保持同步。</translation>
    </message>
    <message>
        <source>System Settings</source>
        <translation>系统设置</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>网络</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>声音</translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation>鼠标</translation>
    </message>
    <message>
        <source>Updates</source>
        <translation>更新</translation>
    </message>
    <message>
        <source>Dock</source>
        <translation>任务栏</translation>
    </message>
    <message>
        <source>Launcher</source>
        <translation>启动器</translation>
    </message>
    <message>
        <source>Wallpaper</source>
        <translation>壁纸</translation>
    </message>
    <message>
        <source>Theme</source>
        <translation>主题</translation>
    </message>
    <message>
        <source>Power</source>
        <translation>电源</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>全选</translation>
    </message>
    <message>
        <source>Unselect All</source>
        <translation>取消全选</translation>
    </message>
    <message>
        <source>Clear cloud data</source>
        <translation>清除云端数据</translation>
    </message>
    <message>
        <source>Are you sure you want to clear your system settings and personal data saved in the cloud?</source>
        <translation>确定要清除您保存在云端的系统设置和个人数据吗？</translation>
    </message>
    <message>
        <source>Once the data is cleared, it cannot be recovered!</source>
        <translation>数据清除后将无法恢复！</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>清 除</translation>
    </message>
    <message>
        <source>Syncing...</source>
        <translation>正在同步，请稍候...</translation>
    </message>
    <message>
        <source>Last sync: %1</source>
        <translation>最近同步时间：%1</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>确 定</translation>
    </message>
    <message>
        <source>Link local accounts to deepin ID</source>
        <translation>deepin ID绑定本地账户</translation>
    </message>
    <message>
        <source>If linked, you can use deepin ID to log in and reset passwords of local accounts. Switch it off to get them unlinked.</source>
        <translation>绑定本地账户，以使用deepin ID登录本地账户和重置本地账户密码。您可以通过关闭开关以解除绑定。</translation>
    </message>
    <message>
        <source>Trusted devices</source>
        <translation>受信任设备</translation>
    </message>
    <message>
        <source>Manage trusted devices to keep your deepin ID secure.</source>
        <translation>管理受信任的设备，以确保您的deepin ID安全性。</translation>
    </message>
    <message>
        <source>OS version: %1</source>
        <translation>系统版本：%1</translation>
    </message>
    <message>
        <source>In use</source>
        <translation>当前设备</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>移除</translation>
    </message>
    <message>
        <source>Are you sure you want to
remove this device from trusted devices?</source>
        <translation>确定从信任设备中移除该设备？</translation>
    </message>
    <message>
        <source>Cloud Service of deepin ID</source>
        <translation>deepin ID云服务</translation>
    </message>
    <message>
        <source>Manage your deepin ID and sync your personal data across devices.
Sign in to deepin ID to get personalized features and services of Browser, App Store, Support, and more.</source>
        <translation>管理您的deepin ID，将您的个人数据在不同设备之间同步。
登录deepin ID以获取浏览器、应用商店、服务与支持等众多应用的个性功能和服务。</translation>
    </message>
    <message>
        <source>Sign In to deepin ID</source>
        <translation>登录deepin ID</translation>
    </message>
    <message>
        <source>deepin Cloud</source>
        <translation>deepin Cloud</translation>
    </message>
    <message>
        <source>Devices and Local Accounts</source>
        <translation>设备与本地账户</translation>
    </message>
    <message>
        <source>Account Info</source>
        <translation>账户信息</translation>
    </message>
    <message>
        <source>The feature is not available at present, please activate your system first</source>
        <translation>当前系统未激活，暂无法使用该功能</translation>
    </message>
    <message>
        <source>Trusted phone numbers and email addresses</source>
        <translation>受信任的手机号和邮箱</translation>
    </message>
    <message>
        <source>Use the trusted mobile number or email address to sign in to deepin ID, and verify sensitive operations if they are performed on deepin ID.</source>
        <translation>通过受信任的手机和邮箱登录您的deepin ID，并在账号进行敏感操作时做可信验证。</translation>
    </message>
    <message>
        <source>Link phone number to deepin ID</source>
        <translation>deepin ID手机号绑定</translation>
    </message>
    <message>
        <source>Link email address to deepin ID</source>
        <translation>deepin ID邮箱绑定</translation>
    </message>
    <message>
        <source>Link third-party accounts</source>
        <translation>第三方账号绑定</translation>
    </message>
    <message>
        <source>Securely and quickly log in to your deepin ID and local account by scanning the QR code with the linked WeChat.</source>
        <translation>通过关联微信扫码，安全且快速地登录您的deepin ID和本地账户。</translation>
    </message>
    <message>
        <source>If unlinked, you will not be able to use WeChat to sign in to deepin ID.</source>
        <translation>解除与该微信的绑定关系，将不能使用微信扫码登录。</translation>
    </message>
    <message>
        <source>Are you sure you want to unlink it?</source>
        <translation>确定解绑？</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>密码管理</translation>
    </message>
    <message>
        <source>Change your deepin ID password regularly to ensure its security.</source>
        <translation>定期更新deepin ID密码，以确保账户安全性。</translation>
    </message>
    <message>
        <source>Change password</source>
        <translation>修改密码</translation>
    </message>
    <message>
        <source>Password changed</source>
        <translation>密码修改成功</translation>
    </message>
    <message>
        <source>Operation failed, please try later</source>
        <translation>操作失败，请稍后再试</translation>
    </message>
    <message>
        <source>Operation Successful</source>
        <translation>操作成功</translation>
    </message>
    <message>
        <source>Reset password successfully</source>
        <translation>密码重置成功</translation>
    </message>
    <message>
        <source>Phone number</source>
        <translation>请输入您的手机号</translation>
    </message>
    <message>
        <source>Email address</source>
        <translation>请输入您的邮箱</translation>
    </message>
    <message>
        <source>Enter a correct phone number</source>
        <translation>请输入正确的手机号</translation>
    </message>
    <message>
        <source>Enter a correct email address</source>
        <translation>请输入正确的邮箱</translation>
    </message>
    <message>
        <source>Use another phone number</source>
        <translation>更换手机号</translation>
    </message>
    <message>
        <source>Use another email address</source>
        <translation>更换邮箱</translation>
    </message>
    <message>
        <source>Link</source>
        <translation>绑定</translation>
    </message>
    <message>
        <source>Unlink</source>
        <translation>解绑</translation>
    </message>
    <message>
        <source>Unlinked</source>
        <translation>未绑定</translation>
    </message>
    <message>
        <source>Change</source>
        <translation>修改</translation>
    </message>
    <message>
        <source>Wrong password, %1 chances left</source>
        <translation>密码错误，您还可以尝试%1次</translation>
    </message>
    <message>
        <source>The login error has reached the limit today. You can reset the password and try again.</source>
        <translation>密码错误已达今日上限，可重置密码再试</translation>
    </message>
    <message>
        <source>The phone number has been linked to deepin ID: %1.
Please check and choose one action below.</source>
        <translation>该手机号已绑定账号%1，请确认后选择以下操作</translation>
    </message>
    <message>
        <source>The email address has been linked to deepin ID: %1.
Please check and choose one action below.</source>
        <translation>该邮箱已绑定账号%1，请确认后选择以下操作</translation>
    </message>
    <message>
        <source>Security Verification</source>
        <translation>安全验证</translation>
    </message>
    <message>
        <source>The action is sensitive, please enter the login password first</source>
        <translation>您正在进行敏感操作，请进行登录密码认证</translation>
    </message>
    <message>
        <source>Change deepin ID password</source>
        <translation>deepin ID密码修改</translation>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation>忘记密码？</translation>
    </message>
    <message>
        <source>Link to current deepin ID</source>
        <translation>换绑本账号</translation>
    </message>
    <message>
        <source>Set a Password</source>
        <translation>设置密码</translation>
    </message>
    <message>
        <source>Get Code</source>
        <translation>获取验证码</translation>
    </message>
    <message>
        <source>Verification code</source>
        <translation>请输入验证码</translation>
    </message>
    <message>
        <source>Resend (%1s)</source>
        <translation>重新发送 (%1s)</translation>
    </message>
    <message>
        <source>Enter a correct verification code</source>
        <translation>请输入正确的验证码</translation>
    </message>
    <message>
        <source>Link WeChat to deepin ID</source>
        <translation>deepin ID微信绑定</translation>
    </message>
    <message>
        <source>Scan QR code with WeChat</source>
        <translation>请使用微信扫码</translation>
    </message>
    <message>
        <source>Password must contain numbers and letters</source>
        <translation>密码必须包含数字和字母</translation>
    </message>
    <message>
        <source>Password must be between 8 and 64 characters</source>
        <translation>密码长度必须为8~64个字符</translation>
    </message>
    <message>
        <source>8-64 characters</source>
        <translation>请输入8-64位密码</translation>
    </message>
    <message>
        <source>Passwords don&apos;t match</source>
        <translation>两次密码输入不一致</translation>
    </message>
    <message>
        <source>Repeat the password</source>
        <translation>请再次输入密码</translation>
    </message>
    <message>
        <source>8-64 characters, including uppercase or lowercase English letters and numbers</source>
        <translation>密码由8-64位大小写字母和数字组成</translation>
    </message>
    <message>
        <source>Invalid nickname, please enter a new one</source>
        <translation>昵称不符合规范，请重新输入</translation>
    </message>
    <message>
        <source>The nickname cannot contain special characters (&apos;&lt;&gt;&amp;&quot;) and whitespaces</source>
        <translation>昵称不能包含&lt;、&gt;、&amp;、&apos;、&quot;和空格</translation>
    </message>
    <message>
        <source>The nickname can be modified only once a day</source>
        <translation>昵称每天仅可修改一次</translation>
    </message>
</context>
</TS>

==> deepin-deepinid-plugin_2.0.9.tar.xz: BUILD/translations/dcc-deepinid-plugin_zh_CN.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_CN">
<context>
    <name>LoginInfoPage</name>
    <message>
        <source>Edit account</source>
        <translation>编辑账号信息</translation>
    </message>
    <message>
        <source>Sign out</source>
        <translation>退出登录</translation>
    </message>
    <message>
        <source>The nickname must be 1~32 characters long</source>
        <translation>昵称长度必须为1~32个字符</translation>
    </message>
    <message>
        <source>The full name is too long</source>
        <translation>名称过长</translation>
    </message>
    <message>
        <source>Mainland China</source>
        <translation>中国大陆</translation>
    </message>
    <message>
        <source>Other regions</source>
        <translation>港澳台及其他地区</translation>
    </message>
</context>
<context>
    <name>SyncModule</name>
    <message>
        <source>deepin ID</source>
        <translation>deepin ID</translation>
    </message>
    <message>
        <source>UOS ID</source>
        <translation>UOS ID</translation>
    </message>
    <message>
        <source>Cloud sync, app store and etc</source>
        <translation>云同步、应用商店等</translation>
    </message>
</context>
<context>
    <name>TransString</name>
    <message>
        <source>deepin Cloud Sync</source>
        <translation>deepin Cloud同步</translation>
    </message>
    <message>
        <source>Subject to your local laws and regulations, it is currently unavailable in your region.</source>
        <translation>受限于您当地的法律法规，UOS Cloud暂未覆盖您所在地区，敬请期待。</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取 消</translation>
    </message>
    <message>
        <source>Securely store system settings and personal data in the cloud, and keep them in sync across devices.</source>
        <translation>将您的系统设置和个人信息安全地存储在云端，并在您不同的设备上保持同步。</translation>
    </message>
    <message>
        <source>System Settings</source>
        <translation>系统设置</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>网络</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>声音</translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation>鼠标</translation>
    </message>
    <message>
        <source>Updates</source>
        <translation>更新</translation>
    </message>
    <message>
        <source>Dock</source>
        <translation>任务栏</translation>
    </message>
    <message>
        <source>Launcher</source>
        <translation>启动器</translation>
    </message>
    <message>
        <source>Wallpaper</source>
        <translation>壁纸</translation>
    </message>
    <message>
        <source>Theme</source>
        <translation>主题</translation>
    </message>
    <message>
        <source>Power</source>
        <translation>电源</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>全选</translation>
    </message>
    <message>
        <source>Unselect All</source>
        <translation>取消全选</translation>
    </message>
    <message>
        <source>Clear cloud data</source>
        <translation>清除云端数据</translation>
    </message>
    <message>
        <source>Are you sure you want to clear your system settings and personal data saved in the cloud?</source>
        <translation>确定要清除您保存在云端的系统设置和个人数据吗？</translation>
    </message>
    <message>
        <source>Once the data is cleared, it cannot be recovered!</source>
        <translation>数据清除后将无法恢复！</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>清 除</translation>
    </message>
    <message>
        <source>Syncing...</source>
        <translation>正在同步，请稍候...</translation>
    </message>
    <message>
        <source>Last sync: %1</source>
        <translation>最近同步时间：%1</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>确 定</translation>
    </message>
    <message>
        <source>Link local accounts to deepin ID</source>
        <translation>deepin ID绑定本地账户</translation>
    </message>
    <message>
        <source>If linked, you can use deepin ID to log in and reset passwords of local accounts. Switch it off to get them unlinked.</source>
        <translation>绑定本地账户，以使用deepin ID登录本地账户和重置本地账户密码。您可以通过关闭开关以解除绑定。</translation>
    </message>
    <message>
        <source>Trusted devices</source>
        <translation>受信任设备</translation>
    </message>
    <message>
        <source>Manage trusted devices to keep your deepin ID secure.</source>
        <translation>管理受信任的设备，以确保您的deepin ID安全性。</translation>
    </message>
    <message>
        <source>OS version: %1</source>
        <translation>系统版本：%1</translation>
    </message>
    <message>
        <source>In use</source>
        <translation>当前设备</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>移除</translation>
    </message>
    <message>
        <source>Are you sure you want to
remove this device from trusted devices?</source>
        <translation>确定从信任设备中移除该设备？</translation>
    </message>
    <message>
        <source>Cloud Service of deepin ID</source>
        <translation>deepin ID云服务</translation>
    </message>
    <message>
        <source>Manage your deepin ID and sync your personal data across devices.
Sign in to deepin ID to get personalized features and services of Browser, App Store, and more.</source>
        <translation>管理您的deepin ID，将您的个人数据在不同设备之间同步。
登录deepin ID以获取浏览器、应用商店等众多应用的个性功能和服务。</translation>
    </message>
    <message>
        <source>Sign In to deepin ID</source>
        <translation>登录deepin ID</translation>
    </message>
    <message>
        <source>deepin Cloud</source>
        <translation>deepin Cloud</translation>
    </message>
    <message>
        <source>Devices and Local Accounts</source>
        <translation>设备与本地账户</translation>
    </message>
    <message>
        <source>Account Info</source>
        <translation>账户信息</translation>
    </message>
    <message>
        <source>The feature is not available at present, please activate your system first</source>
        <translation>当前系统未激活，暂无法使用该功能</translation>
    </message>
    <message>
        <source>Trusted phone numbers and email addresses</source>
        <translation>受信任的手机号和邮箱</translation>
    </message>
    <message>
        <source>Use the trusted mobile number or email address to sign in to deepin ID, and verify sensitive operations if they are performed on deepin ID.</source>
        <translation>通过受信任的手机和邮箱登录您的deepin ID，并在账号进行敏感操作时做可信验证。</translation>
    </message>
    <message>
        <source>Link phone number to deepin ID</source>
        <translation>deepin ID手机号绑定</translation>
    </message>
    <message>
        <source>Link email address to deepin ID</source>
        <translation>deepin ID邮箱绑定</translation>
    </message>
    <message>
        <source>Link third-party accounts</source>
        <translation>第三方账号绑定</translation>
    </message>
    <message>
        <source>Securely and quickly log in to your deepin ID and local account by scanning the QR code with the linked WeChat.</source>
        <translation>通过关联微信扫码，安全且快速地登录您的deepin ID和本地账户。</translation>
    </message>
    <message>
        <source>If unlinked, you will not be able to use WeChat to sign in to deepin ID.</source>
        <translation>解除与该微信的绑定关系，将不能使用微信扫码登录。</translation>
    </message>
    <message>
        <source>Are you sure you want to unlink it?</source>
        <translation>确定解绑？</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>密码管理</translation>
    </message>
    <message>
        <source>Change your deepin ID password regularly to ensure its security.</source>
        <translation>定期更新deepin ID密码，以确保账户安全性。</translation>
    </message>
    <message>
        <source>Change password</source>
        <translation>修改密码</translation>
    </message>
    <message>
        <source>Password changed</source>
        <translation>密码修改成功</translation>
    </message>
    <message>
        <source>Operation failed, please try later</source>
        <translation>操作失败，请稍后再试</translation>
    </message>
    <message>
        <source>Operation Successful</source>
        <translation>操作成功</translation>
    </message>
    <message>
        <source>Reset password successfully</source>
        <translation>密码重置成功</translation>
    </message>
    <message>
        <source>Phone number</source>
        <translation>请输入您的手机号</translation>
    </message>
    <message>
        <source>Email address</source>
        <translation>请输入您的邮箱</translation>
    </message>
    <message>
        <source>Enter a correct phone number</source>
        <translation>请输入正确的手机号</translation>
    </message>
    <message>
        <source>Enter a correct email address</source>
        <translation>请输入正确的邮箱</translation>
    </message>
    <message>
        <source>Use another phone number</source>
        <translation>更换手机号</translation>
    </message>
    <message>
        <source>Use another email address</source>
        <translation>更换邮箱</translation>
    </message>
    <message>
        <source>Link</source>
        <translation>绑定</translation>
    </message>
    <message>
        <source>Unlink</source>
        <translation>解绑</translation>
    </message>
    <message>
        <source>Unlinked</source>
        <translation>未绑定</translation>
    </message>
    <message>
        <source>Change</source>
        <translation>修改</translation>
    </message>
    <message>
        <source>Wrong password, %1 chances left</source>
        <translation>密码错误，您还可以尝试%1次</translation>
    </message>
    <message>
        <source>The login error has reached the limit today. You can reset the password and try again.</source>
        <translation>密码错误已达今日上限，可重置密码再试</translation>
    </message>
    <message>
        <source>The phone number has been linked to deepin ID: %1.
Please check and choose one action below.</source>
        <translation>该手机号已绑定账号%1，请确认后选择以下操作</translation>
    </message>
    <message>
        <source>The email address has been linked to deepin ID: %1.
Please check and choose one action below.</source>
        <translation>该邮箱已绑定账号%1，请确认后选择以下操作</translation>
    </message>
    <message>
        <source>Security Verification</source>
        <translation>安全验证</translation>
    </message>
    <message>
        <source>The action is sensitive, please enter the login password first</source>
        <translation>您正在进行敏感操作，请进行登录密码认证</translation>
    </message>
    <message>
        <source>Change deepin ID password</source>
        <translation>deepin ID密码修改</translation>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation>忘记密码？</translation>
    </message>
    <message>
        <source>Link to current deepin ID</source>
        <translation>换绑本账号</translation>
    </message>
    <message>
        <source>Set a Password</source>
        <translation>设置密码</translation>
    </message>
    <message>
        <source>Get Code</source>
        <translation>获取验证码</translation>
    </message>
    <message>
        <source>Verification code</source>
        <translation>请输入验证码</translation>
    </message>
    <message>
        <source>Resend (%1s)</source>
        <translation>重新发送 (%1s)</translation>
    </message>
    <message>
        <source>Enter a correct verification code</source>
        <translation>请输入正确的验证码</translation>
    </message>
    <message>
        <source>Link WeChat to deepin ID</source>
        <translation>deepin ID微信绑定</translation>
    </message>
    <message>
        <source>Scan QR code with WeChat</source>
        <translation>请使用微信扫码</translation>
    </message>
    <message>
        <source>Password must contain numbers and letters</source>
        <translation>密码必须包含数字和字母</translation>
    </message>
    <message>
        <source>Password must be between 8 and 64 characters</source>
        <translation>密码长度必须为8~64个字符</translation>
    </message>
    <message>
        <source>8-64 characters</source>
        <translation>请输入8-64位密码</translation>
    </message>
    <message>
        <source>Passwords don&apos;t match</source>
        <translation>两次密码输入不一致</translation>
    </message>
    <message>
        <source>Repeat the password</source>
        <translation>请再次输入密码</translation>
    </message>
    <message>
        <source>8-64 characters, including uppercase or lowercase English letters and numbers</source>
        <translation>密码由8-64位大小写字母和数字组成</translation>
    </message>
    <message>
        <source>Invalid nickname, please enter a new one</source>
        <translation>昵称不符合规范，请重新输入</translation>
    </message>
    <message>
        <source>The nickname cannot contain special characters (&apos;&lt;&gt;&amp;&quot;) and whitespaces</source>
        <translation>昵称不能包含&lt;、&gt;、&amp;、&apos;、&quot;和空格</translation>
    </message>
    <message>
        <source>The nickname can be modified only once a day</source>
        <translation>昵称每天仅可修改一次</translation>
    </message>
</context>
</TS>
